.. _bob.fusion.base.api:

==========
Python API
==========

This section includes information for using the Python API of
``bob.fusion.base``.


Summary
=======

Algorithms
----------

.. autosummary::
    bob.fusion.base.algorithm.Algorithm
    bob.fusion.base.algorithm.AlgorithmBob
    bob.fusion.base.algorithm.Weighted_Sum
    bob.fusion.base.algorithm.GMM

Preprocessors
-------------

.. autosummary::
    bob.fusion.base.preprocessor.Tanh
    bob.fusion.base.preprocessor.ZNorm

Fusion Algorithms
=================

.. automodule:: bob.fusion.base.algorithm
    :members:
    :undoc-members:
    :special-members: __init__


Fusion Preprocessors
====================

.. automodule:: bob.fusion.base.preprocessor
    :members:
    :undoc-members:
    :special-members: __init__


Fusion Scripts
==============

.. automodule:: bob.fusion.base.script
    :members:
    :undoc-members:
